@@ -164,6 +164,8 @@ def _parse_query_key(node, pattern, include_parent_, **q):
     if not node._key:
         return False, None
 
+    if pattern == "*":
+        pattern = ".*"
     if isinstance(pattern, str):
         pattern = re.compile(pattern)
     elif isinstance(pattern, I):
@@ -174,7 +176,7 @@ def _parse_query_key(node, pattern, include_parent_, **q):
         raise TypeError(f"Argument pattern must be an string or regex pattern")
 
     if not q:
-        raise JSONQueryException(f"Actions are mandatory")
+        q = {"exact": All}
 
     # --------------------
 
@@ -293,12 +295,14 @@ def _parse_query_key(node, pattern, include_parent_, **q):
         result = make_actions(obj, target_actions, query_value)
         if result is False:
             return False, None
+
     return (True, node.parent if include_parent_ else node)
 
 
 @catch_exceptions
 def parse_float(
     s,
+    only_check=False,
     decimal_sep=decimal_separator,
     thousands_sep=thousands_separator,
     fail_silently=False,
@@ -309,15 +313,22 @@ def parse_float(
     if isinstance(s, bool):
         raise JSONSingletonException("s argument cannot be boolean type")
     try:
-        return float(s)
+        result = float(s)
     except Exception:
-        pass
-
+        if only_check:
+            return False
+    else:
+        if only_check:
+            return True
+        else:
+            return result
     match = re.fullmatch(
         fr"\s*(?:[\$€]*\s*([+-])?\s*|([+-])?\s*[\$€]*\s*)([0-9{thousands_sep}]+)({decimal_sep}[0-9]+)?\s*[\$€]*\w{{,10}}\s*",
         s,
     )
     if not match:
+        if only_check:
+            return False
         raise JSONSingletonException(
             f"Target string does not match a float number: {s}"
         )
@@ -439,6 +450,12 @@ def parse_datetime(
     raise JSONSingletonException(f"Can't parse target datetime: {s}")
 
 
+@catch_exceptions
+def parse_timestamp(s, **kwargs):
+    result = int(parse_datetime(s, **kwargs).timestamp() * 1000)
+    return result
+
+
 @catch_exceptions
 def parse_bool(s, fail_silently=False):
     from jsonutils.base import JSONBool
@@ -460,19 +477,44 @@ def parse_json(s):
     pass
 
 
-def url_validator(url, public=False):
+@catch_exceptions
+def parse_http_url(url, fail_silently=False):
+
+    if not isinstance(url, str):
+        raise TypeError(f"Argument url must be an str instance, not {type(url)}")
+
+    match = url_validator(url, return_match=True, optative_protocol=True)
+
+    if match:
+        protocol = match.groupdict().get("protocol")
+
+        if not protocol:
+            return "http://" + url
+        elif protocol not in ("http", "https"):
+            raise Exception(f"Url's protocol is not http: {protocol}")
+        else:  # a protocol already exists
+            return url
+
+    else:
+        raise Exception(f"Can't parse a valid url: {url}")
+
+
+def url_validator(url, public=False, return_match=False, optative_protocol=False):
     """
     :param value: URL address string to validate
     :param public: (default=False) Set True to only allow a public IP address
+    :param return_match: (default=False) Set True to return match instead of bool
     """
 
     ip_middle_octet = r"(?:\.(?:1?\d{1,2}|2[0-4]\d|25[0-5]))"
     ip_last_octet = r"(?:\.(?:0|[1-9]\d?|1\d\d|2[0-4]\d|25[0-5]))"
 
+    prot = "?" if optative_protocol else ""
+
     regex = re.compile(  # noqa: W605
         r"^"
         # protocol identifier
-        r"(?:(?:https?|ftp)://)"
+        rf"(?:(?P<protocol>https?|ftp)://){prot}"
         # user:pass authentication
         r"(?:[-a-z\u00a1-\uffff0-9._~%!$&'()*+,;=:]+"
         r"(?::[-a-z0-9._~%!$&'()*+,;=:]*)?@)?"
@@ -553,6 +595,10 @@ def url_validator(url, public=False):
     pattern = re.compile(regex)
 
     result = pattern.match(url)
+
+    if return_match:
+        return result
+
     if not public:
         return bool(result)
 
