@@ -228,7 +228,7 @@ class ValuesList(list):
         # TODO dict option for counting unique values
         unique_values = ValuesList()
         unique_values._root = self._root
-        for idx, item in enumerate(self):
+        for item in self:
             if item not in unique_values:
                 unique_values.append(item)
         return unique_values
@@ -283,15 +283,23 @@ class QuerySet(list):
         # TODO add test for update when callables
         is_callable = callable(new_obj)
 
+        updated_objects = 0
+        not_updated_objects = 0
+
         for item in self:
             path = item.jsonpath.relative_to(self._root)
             if is_callable:
                 try:
                     exec(f"self._root{path} = new_obj(self._root{path})")
                 except Exception:
-                    pass
+                    not_updated_objects += 1
+                else:
+                    updated_objects += 1
             else:
                 exec(f"self._root{path} = new_obj")
+                updated_objects += 1
+
+        return (updated_objects, not_updated_objects)
 
     def distinct(self, transform=None):
         """
@@ -300,10 +308,11 @@ class QuerySet(list):
         ---------
             transform: if selected, then applies such a function on each item in the queryset before checking
         """
+        cls = self.__class__
 
         # TODO add test for this
         # TODO dict option for counting unique values
-        unique_values = QuerySet()
+        unique_values = cls()
         unique_values._root = self._root
         unique_values._native_types = self._native_types
 
@@ -328,7 +337,10 @@ class QuerySet(list):
 
     def filter(self, **q):
         # TODO add test
-        output = QuerySet()
+
+        cls = self.__class__
+
+        output = cls()
         output._root = self._root
         output._native_types = self._native_types
 
@@ -368,8 +380,10 @@ class QuerySet(list):
         # TODO
         rever = True if key.startswith("-") else False
 
+        cls = self.__class__
+
         try:
-            result = QuerySet(
+            result = cls(
                 sorted(
                     self,
                     key=lambda x: x.parent._get(key.replace("-", "").strip(), ""),
@@ -399,12 +413,13 @@ class QuerySet(list):
         return result
 
     def __repr__(self):
-        return "<QuerySet " + super().__repr__() + ">"
+        clsname = self.__class__.__name__
+        return f"<{clsname} " + super().__repr__() + ">"
 
 
 class KeyQuerySet(QuerySet):
     """
-    This is a QuerySet but with more methods for querying keys
+    This is a QuerySet, with all its methods, but adding more useful ones for querying keys.
     """
 
     def keys(self):
