@@ -22,10 +22,15 @@ class JsonTest(unittest.TestCase):
 
         self.assertIsInstance(test.get(A=js.All), bool)
         self.assertIsInstance(test.get(B=js.All), type(None))
-        self.assertIsInstance(test.get(D=js.All), dict)
-        self.assertIsInstance(test.get(L=js.All), list)
+        self.assertEqual(type(test.get(D=js.All)), dict)
+        self.assertEqual(type(test.get(L=js.All)), list)
 
         self.assertIsInstance(test.query(A=js.All).first(), bool)
         self.assertIsInstance(test.query(A=js.All).last(), bool)
         self.assertIsInstance(test.query(B=js.All).first(), type(None))
         self.assertIsInstance(test.query(B=js.All).last(), type(None))
+
+        self.assertEqual(type(test.query(A=True).order_by("A").first()), bool)
+        self.assertEqual(type(test.query(B=None).order_by("B").first()), type(None))
+        self.assertEqual(type(test.query(D__type=dict).order_by("D").first()), dict)
+        self.assertEqual(type(test.query(L__type=list).order_by("L").first()), list)
