@@ -203,6 +203,22 @@ class JsonTest(unittest.TestCase):
         self.assertEqual(JSONBool(False), False)
         self.assertFalse(JSONBool(True) < 3)
         self.assertIn(None, JSONList([None, 1]))
+        self.assertTrue(JSONBool(True) != False)
+        self.assertTrue(JSONBool(True) == True)
+        self.assertFalse(JSONBool(True) != True)
+        self.assertFalse(JSONBool(True) == False)
+        self.assertTrue(JSONBool(False) != True)
+        self.assertTrue(JSONBool(False) == False)
+        self.assertFalse(JSONBool(False) != False)
+        self.assertFalse(JSONBool(False) == True)
+        self.assertTrue(bool(JSONBool(True)) != False)
+        self.assertTrue(bool(JSONBool(True)) == True)
+        self.assertFalse(bool(JSONBool(True)) != True)
+        self.assertFalse(bool(JSONBool(True)) == False)
+        self.assertTrue(bool(JSONBool(False)) != True)
+        self.assertTrue(bool(JSONBool(False)) == False)
+        self.assertFalse(bool(JSONBool(False)) != False)
+        self.assertFalse(bool(JSONBool(False)) == True)
 
     def test_dict_comparison_methods(self):
         self.assertEqual(JSONDict(a=1, b=2), dict(b=2, a=1))
